''' A telegram bot that applies watermark on images, gifs and videos. '''


from telewater.main import start_bot

__version__ = "0.0.6"

# AAHNIK 2021
